// Grin LISP
// Copyright (C) 2001 Daniel Beer
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#include "lisp.h"

string
lisp::str::print(void) const {
  string out("\"");
  for(unsigned int i=0;i<data.size();i++)
    if(data[i]=='"') out+="\\\"";
    else out+=data[i];
  out+='"';
  return out;
}

bool
lisp::str::equal(object x) const {
  return is_str(x)&&assume_str(x).data==data;
}

int
lisp::str::recursive_mark(void) {
  if(get_mark()) return 0;
  set_mark(true);
  return 1;
}

const char *
lisp::str::get_typeof(void) const {
  return "STRING";
}
